History
=======

0.4.2 (2015-05-31)
------------------

* Fixes #7 not handling the failure of python setup egg_info.
* Adds py_deps.exceptions module.
* Adds py_deps.logger module.
* Fixes issues of DistributionNotFound, InstallationErrror.

0.4.1 (2015-05-28)
------------------

* Adds Container.list_data method.
* Unsupports wheel format for distribution.

0.4.0 (2015-05-20)
------------------

* Searching packages from PyPI.

0.3.0 (2015-05-12)
------------------

* Supports NetworkX DiGraph objects.
* Changes to use mock instead of pip.req.RequirementSet.prepare_files.
* Coverage 98% over.

0.2.0 (2015-05-10)
------------------

* Cache the parsed dependencies.
* Fixes setting the url of node and targets.

0.1.1 (2015-05-08)
------------------

* Fixes test data of pretty_print, linkdraw.

0.1.0 (2015-05-07)
------------------

* Supports generating linkdraw data.
* Supports pip 6.1.1 over.
* Supports wheel format for distribution.
* Adds unit tests.

0.0.1 (2015-04-29)
------------------

* First release
